California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| CAMPAIGN FINANCE: Candidates & Elected Officials
Choose a Listing: Certified Election Candidates Incumbent Elected State Officials Candidates and Elected Officials By Name Who filed a Statement of Intention to run for What State Office? (Filers may not have qualified for the ballot) CalPERS and CalSTRS Candidate Filings, Scanned Images | Go to Section:
| Statewide Candidates
| State Senate Candidates
| State Assembly Candidates
Choose an Election: 2022 GENERAL Prior Elections
Also check Late Contribution filings. These reports are independent of the comprehensive disclosure reports that are linked here until semi-annual filings are submitted.
STATEWIDE OFFICES
GOVERNOR
DAHLE, BRIAN NEWSOM, GAVIN
| LIEUTENANT GOVERNOR
KOUNALAKIS, ELENI UNDERWOOD JACOBS, ANGELA E.
SECRETARY OF STATE
BERNOSKY, ROBERT E. WEBER, SHIRLEY
| CONTROLLER
CHEN, LANHEE J. COHEN, MALIA M.
TREASURER
GUERRERO, JACK M. MA, FIONA
| ATTORNEY GENERAL
BONTA, ROB HOCHMAN, NATHAN
SUPERINTENDENT OF PUBLIC INSTRUCTION
CHRISTENSEN, LANCE THURMOND, TONY
| INSURANCE COMMISSIONER
HOWELL, ROBERT P. LARA, RICARDO
BOARD OF EQUALIZATION
MEMBER BOARD OF EQUALIZATION 01
ALTAMIRANO, JOSE S. GAINES, EDWARD MOORE
| MEMBER BOARD OF EQUALIZATION 02
LIEBER, SALLY VERBICA, PETER C.
MEMBER BOARD OF EQUALIZATION 03
MANVEL, YANA M. VAZQUEZ, ANTONIO
| MEMBER BOARD OF EQUALIZATION 04
DODSON, DAVID B. SCHAEFER, J. MICHAEL
SENATE DISTRICTS
STATE SENATE 02
MC GUIRE, MIKE YOON, GINSU 'GENE'
| STATE SENATE 04
ALVARADO-GIL, MARIE I. ROBERTSON, TIMOTHY W.
STATE SENATE 06
NIELLO, ROGER VILLESCAZ, PAULA
| STATE SENATE 08
ASHBY, ANGELIQUE JONES, DAVE
STATE SENATE 10
MEI, LILY WAHAB, AISHA
| STATE SENATE 12
GROVE, SHANNON GUNDY, SUSANNE
STATE SENATE 14
CABALLERO, ANNA SHOR, AMNON
| STATE SENATE 16
HURTADO, MELISSA SHEPARD, DAVID E
STATE SENATE 18
GALICIA, ALEJANDRO PADILLA, STEVE
| STATE SENATE 20
HERTZBERG, DANIEL MENJIVAR, CAROLINE
STATE SENATE 22
RUBIO, SUSAN TSAI, VINCENT
| STATE SENATE 24
ALLEN, BEN IRWIN, KRISTINA
STATE SENATE 26
AGRAZ, CLAUDIA DURAZO, MARIA ELENA
| STATE SENATE 28
SMALLWOOD-CUEVAS, LOLA TURNER, CHERYL C.
STATE SENATE 30
ARCHULETA, BOB CLEMMONS, MITCH
| STATE SENATE 32
NASH, BRIAN SEYARTO, KELLY
STATE SENATE 34
SHADER, RHONDA UMBERG, THOMAS J.
| STATE SENATE 36
CARR, KIM NGUYEN, JANET
STATE SENATE 38
BLAKESPEAR, CATHERINE GUNDERSON, MATTHEW
| STATE SENATE 40
JONES, BRIAN W. ROCHA, JOSEPH
ASSEMBLY DISTRICTS
ASSEMBLY 01
DAHLE, MEGAN SANDWITH, BELLE STARR
| ASSEMBLY 02
SVOLOS, CHARLOTTE WOOD, JIM
ASSEMBLY 03
GALLAGHER, JAMES ZINK, DAVID LEON
| ASSEMBLY 04
AGUIAR-CURRY, CECILIA PRITCHARD, BRYAN T.
ASSEMBLY 05
CHENOWETH, REBECCA L. PATTERSON, JOE
| ASSEMBLY 06
COOK, CATHERINE M. MC CARTY, KEVIN
ASSEMBLY 07
COOLEY, KEN HOOVER, JOSH
| ASSEMBLY 08
NICHOLS, THOMAS E PATTERSON, JIM
ASSEMBLY 09
FLORA, HEATH TAHIRKHELI, MUSHTAQ A.
| ASSEMBLY 10
GUERRA, ERIC NGUYEN, STEPHANIE
ASSEMBLY 11
CALLISON, JENNY L. WILSON, LORI
| ASSEMBLY 12
AMINZADEH, SARA CONNOLLY, DAMON
ASSEMBLY 13
VARGAS, VERONICA VILLAPUDUA, CARLOS
| ASSEMBLY 14
KINNEY, RICHARD WICKS, BUFFY
ASSEMBLY 15
GRAYSON, TIM PROCTOR, JANELL
| ASSEMBLY 16
BAUER-KAHAN, REBECCA RUBAY, JOSEPH A.
ASSEMBLY 17
CAMPOS, DAVID F. HANEY, MATT
| ASSEMBLY 18
BONTA, MIA PECHENUK, MINDY
ASSEMBLY 19
TING, PHIL WEIDE, KARSTEN
| ASSEMBLY 20
KUMAGAI, SHAWN ORTEGA-TORO, LIZ
ASSEMBLY 21
HALE, GISELLE PAPAN, DIANE
| ASSEMBLY 22
ALANIS, JUAN SELF, JESSICA S.
ASSEMBLY 23
BERMAN, MARC E. DEC, TIM
| ASSEMBLY 24
BRUNTON, ROBERT L. LEE, ALEX T.
ASSEMBLY 25
KALRA, ASH STROLL, THEODORE J.
| ASSEMBLY 26
GORSULOWSKY, TIM S. LOW, EVAN
ASSEMBLY 27
PAZIN, MARK N. SORIA, ESMERALDA
| ASSEMBLY 28
LAWLER, LIZ PELLERIN, GAIL
ASSEMBLY 29
CASTRO, STEPHANIE L. RIVAS, ROBERT
| ASSEMBLY 30
ADDIS, DAWN J. NOHRDEN, VICKI L.
ASSEMBLY 31
ARAMBULA, JOAQUIN CALANDRA, DOLCE M.
| ASSEMBLY 32
FONG, VINCENT
ASSEMBLY 33
MATHIS, DEVON J. SIGALA, JOSE
| ASSEMBLY 34
LACKEY, THOMAS W. SMITH, THURSTON
ASSEMBLY 35
BAINS, JASMEET PEREZ, LETICIA
| ASSEMBLY 36
GARCIA, EDUARDO WEEKS, IAN MICHAEL
ASSEMBLY 37
HART, GREGG A, STOKER, MIKE
| ASSEMBLY 38
BENNETT, STEPHEN A. BROCATO, COLE C.
ASSEMBLY 39
CARRILLO, JUAN MARSH, PAUL A.
| ASSEMBLY 40
SCHIAVO, PILAR VALLADARES, SUZETTE M.
ASSEMBLY 41
HOLDEN, CHRIS MC MAHON, MICHAEL B.
| ASSEMBLY 42
IRWIN, JACQUI V. MILLS, LORI
ASSEMBLY 43
MASSAQUOI, SIAKA RIVAS, LUZ
| ASSEMBLY 44
FRIEDMAN, LAURA JACOBSEN, BARRY CURTIS
ASSEMBLY 45
MARTINEZ, JOSEPH W. RAMOS, JAMES
| ASSEMBLY 46
CARUSO, DANA FRANCES GABRIEL, JESSE
ASSEMBLY 47
HOLSTEGE, CHRISTY WALLIS, GREG
| ASSEMBLY 48
MAYE, RYAN RUBIO, BLANCA
ASSEMBLY 49
BRINK, BURTON FONG, MICHAEL
| ASSEMBLY 50
REYES, ELOISE GOMEZ STARK, SHEELA
ASSEMBLY 51
ABRAMSON, LOUIS E. ZBUR, RICK CHAVEZ
| ASSEMBLY 52
CARRILLO, WENDY LIVAS PORTER, MIA
ASSEMBLY 53
HOLLE, TONI M. RODRIGUEZ, FREDDIE
| ASSEMBLY 54
ALANIZ, ELAINE SANTIAGO, MIGUEL
ASSEMBLY 55
BRYAN, ISAAC CASCIO, KEITH G.
| ASSEMBLY 56
CALDERON, LISA MARTINEZ, JESSICA
ASSEMBLY 57
JONES-SAWYER SR., REGINALD BYRON
| ASSEMBLY 58
CERVANTES, SABRINA MURPHY, BERNARD WILLIAM
ASSEMBLY 59
CHEN, PHILLIP SIT, LEON Q.
| ASSEMBLY 60
DIAZ NAVA, HECTOR JACKSON, COREY A.
ASSEMBLY 61
MC KINNOR, TINA PULLEN-MILES, ROBERT
| ASSEMBLY 62
ESTRADA, MARIA RENDON, ANTHONY
ASSEMBLY 63
ESSAYLI, BILL RIZVI, FAUZIA
| ASSEMBLY 64
ORTIZ JR., RAUL PACHECO, BLANCA
ASSEMBLY 65
GIPSON, MIKE IQBAL-ZUBAIR, FATIMA S.
| ASSEMBLY 66
BARKS, GEORGE G. MURATSUCHI, AL
ASSEMBLY 67
QUIRK-SILVA, SHARON YOO, SOO
| ASSEMBLY 68
TARDIF, MIKE VALENCIA, AVELINO
ASSEMBLY 69
AUSTIN, ALVIN R. LOWENTHAL, JOSH
| ASSEMBLY 70
TA, TRI THU-HA NGUYEN, DIEDRE
ASSEMBLY 71
RAHN, MATTHEW SANCHEZ, KATHRYN
| ASSEMBLY 72
DIXON, DIANE MANCUSO, JUDIE
ASSEMBLY 73
CHOI, STEVEN PETRIE-NORRIS, COTTIE
| ASSEMBLY 74
DAVIES, LAURIE A. DUNCAN, CHRIS
ASSEMBLY 75
VOEPEL, RANDY G. WALDRON, MARIE
| ASSEMBLY 76
BRUCE-LANE, KRISTIE MAIENSCHEIN, BRIAN
ASSEMBLY 77
BOERNER HORVATH, TASHA DOWNEY, DANIEL F.
| ASSEMBLY 78
GONZALES, ERIC E. WARD, CHRISTOPHER M.
ASSEMBLY 79
SABOL, CORBIN A. WEBER, AKILAH
| ASSEMBLY 80
ALVAREZ, DAVID GOMEZ, GEORGETTE